==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineExtensionInstanceViewArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineExtensionInstanceViewArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The instance view of a virtual machine extension.
 * @property name The virtual machine extension name.
 * @property statuses The resource status information.
 * @property substatuses The resource status information.
 * @property type Specifies the type of the extension; an example is "CustomScriptExtension".
 * @property typeHandlerVersion Specifies the version of the script handler.
 */
public data class VirtualMachineExtensionInstanceViewArgs(
    public val name: Output<String>? = null,
    public val statuses: Output<List<InstanceViewStatusArgs>>? = null,
    public val substatuses: Output<List<InstanceViewStatusArgs>>? = null,
    public val type: Output<String>? = null,
    public val typeHandlerVersion: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineExtensionInstanceViewArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineExtensionInstanceViewArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineExtensionInstanceViewArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .statuses(
                statuses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .substatuses(
                substatuses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type?.applyValue({ args0 -> args0 }))
            .typeHandlerVersion(typeHandlerVersion?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineExtensionInstanceViewArgs].
 */
@PulumiTagMarker
public class VirtualMachineExtensionInstanceViewArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var statuses: Output<List<InstanceViewStatusArgs>>? = null

    private var substatuses: Output<List<InstanceViewStatusArgs>>? = null

    private var type: Output<String>? = null

    private var typeHandlerVersion: Output<String>? = null

    /**
     * @param value The virtual machine extension name.
     */
    @JvmName("eildhdecdjrwdxjs")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The resource status information.
     */
    @JvmName("criluyvkyckvemcb")
    public suspend fun statuses(`value`: Output<List<InstanceViewStatusArgs>>) {
        this.statuses = value
    }

    @JvmName("xdjbkcudukmxeuqa")
    public suspend fun statuses(vararg values: Output<InstanceViewStatusArgs>) {
        this.statuses = Output.all(values.asList())
    }

    /**
     * @param values The resource status information.
     */
    @JvmName("huygfeuwvxbsxgjl")
    public suspend fun statuses(values: List<Output<InstanceViewStatusArgs>>) {
        this.statuses = Output.all(values)
    }

    /**
     * @param value The resource status information.
     */
    @JvmName("fokbnkesreampnoh")
    public suspend fun substatuses(`value`: Output<List<InstanceViewStatusArgs>>) {
        this.substatuses = value
    }

    @JvmName("gxepqmythoaiksbf")
    public suspend fun substatuses(vararg values: Output<InstanceViewStatusArgs>) {
        this.substatuses = Output.all(values.asList())
    }

    /**
     * @param values The resource status information.
     */
    @JvmName("lqlhvudbwnshyhxr")
    public suspend fun substatuses(values: List<Output<InstanceViewStatusArgs>>) {
        this.substatuses = Output.all(values)
    }

    /**
     * @param value Specifies the type of the extension; an example is "CustomScriptExtension".
     */
    @JvmName("uldrmglxjpbbgbey")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specifies the version of the script handler.
     */
    @JvmName("qqqtssaawlsaemmr")
    public suspend fun typeHandlerVersion(`value`: Output<String>) {
        this.typeHandlerVersion = value
    }

    /**
     * @param value The virtual machine extension name.
     */
    @JvmName("ukjfsjcplulleeru")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The resource status information.
     */
    @JvmName("lcgqfhdvuaufccnv")
    public suspend fun statuses(`value`: List<InstanceViewStatusArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.statuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("wcileapkfuwwbtce")
    public suspend fun statuses(argument: List<suspend InstanceViewStatusArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            InstanceViewStatusArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("phmnlnitrkmfghtx")
    public suspend fun statuses(vararg argument: suspend InstanceViewStatusArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            InstanceViewStatusArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("wikhjkcmmesijvjn")
    public suspend fun statuses(argument: suspend InstanceViewStatusArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(InstanceViewStatusArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.statuses = mapped
    }

    /**
     * @param values The resource status information.
     */
    @JvmName("dokyxirokhqxpgrs")
    public suspend fun statuses(vararg values: InstanceViewStatusArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statuses = mapped
    }

    /**
     * @param value The resource status information.
     */
    @JvmName("ogvlorythjmxcruo")
    public suspend fun substatuses(`value`: List<InstanceViewStatusArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.substatuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("txtpenayhvylnkdw")
    public suspend fun substatuses(argument: List<suspend InstanceViewStatusArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            InstanceViewStatusArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.substatuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("sgnxtbbhlpwnycha")
    public suspend fun substatuses(
        vararg
        argument: suspend InstanceViewStatusArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            InstanceViewStatusArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.substatuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("borbugyxynquigkp")
    public suspend fun substatuses(argument: suspend InstanceViewStatusArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(InstanceViewStatusArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.substatuses = mapped
    }

    /**
     * @param values The resource status information.
     */
    @JvmName("xjquclbdvtamhefp")
    public suspend fun substatuses(vararg values: InstanceViewStatusArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.substatuses = mapped
    }

    /**
     * @param value Specifies the type of the extension; an example is "CustomScriptExtension".
     */
    @JvmName("qabddkelbibymqbd")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Specifies the version of the script handler.
     */
    @JvmName("hielbpebraylgous")
    public suspend fun typeHandlerVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.typeHandlerVersion = mapped
    }

    internal fun build(): VirtualMachineExtensionInstanceViewArgs =
        VirtualMachineExtensionInstanceViewArgs(
            name = name,
            statuses = statuses,
            substatuses = substatuses,
            type = type,
            typeHandlerVersion = typeHandlerVersion,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineExtensionInstanceViewArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineExtensionInstanceViewArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The instance view of a virtual machine extension.
 * @property name The virtual machine extension name.
 * @property statuses The resource status information.
 * @property substatuses The resource status information.
 * @property type Specifies the type of the extension; an example is "CustomScriptExtension".
 * @property typeHandlerVersion Specifies the version of the script handler.
 */
public data class VirtualMachineExtensionInstanceViewArgs(
    public val name: Output<String>? = null,
    public val statuses: Output<List<InstanceViewStatusArgs>>? = null,
    public val substatuses: Output<List<InstanceViewStatusArgs>>? = null,
    public val type: Output<String>? = null,
    public val typeHandlerVersion: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineExtensionInstanceViewArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineExtensionInstanceViewArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineExtensionInstanceViewArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .statuses(
                statuses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .substatuses(
                substatuses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type?.applyValue({ args0 -> args0 }))
            .typeHandlerVersion(typeHandlerVersion?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineExtensionInstanceViewArgs].
 */
@PulumiTagMarker
public class VirtualMachineExtensionInstanceViewArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var statuses: Output<List<InstanceViewStatusArgs>>? = null

    private var substatuses: Output<List<InstanceViewStatusArgs>>? = null

    private var type: Output<String>? = null

    private var typeHandlerVersion: Output<String>? = null

    /**
     * @param value The virtual machine extension name.
     */
    @JvmName("kbydmvflmlkeyemc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The resource status information.
     */
    @JvmName("tcdaskfavtekyubw")
    public suspend fun statuses(`value`: Output<List<InstanceViewStatusArgs>>) {
        this.statuses = value
    }

    @JvmName("gageliavqecthuoo")
    public suspend fun statuses(vararg values: Output<InstanceViewStatusArgs>) {
        this.statuses = Output.all(values.asList())
    }

    /**
     * @param values The resource status information.
     */
    @JvmName("gyxnmgdvdcbjugnr")
    public suspend fun statuses(values: List<Output<InstanceViewStatusArgs>>) {
        this.statuses = Output.all(values)
    }

    /**
     * @param value The resource status information.
     */
    @JvmName("gfrpseghduenainq")
    public suspend fun substatuses(`value`: Output<List<InstanceViewStatusArgs>>) {
        this.substatuses = value
    }

    @JvmName("wlfoqfoqxslhjroc")
    public suspend fun substatuses(vararg values: Output<InstanceViewStatusArgs>) {
        this.substatuses = Output.all(values.asList())
    }

    /**
     * @param values The resource status information.
     */
    @JvmName("rykgsctofeagxbcr")
    public suspend fun substatuses(values: List<Output<InstanceViewStatusArgs>>) {
        this.substatuses = Output.all(values)
    }

    /**
     * @param value Specifies the type of the extension; an example is "CustomScriptExtension".
     */
    @JvmName("abgxfbuprocqrjqu")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specifies the version of the script handler.
     */
    @JvmName("taombbpeconrtllj")
    public suspend fun typeHandlerVersion(`value`: Output<String>) {
        this.typeHandlerVersion = value
    }

    /**
     * @param value The virtual machine extension name.
     */
    @JvmName("vyhsfnnxfaxquxus")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The resource status information.
     */
    @JvmName("hojmlvebwhveomgj")
    public suspend fun statuses(`value`: List<InstanceViewStatusArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.statuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("nyjsqfxmkldmosdw")
    public suspend fun statuses(argument: List<suspend InstanceViewStatusArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            InstanceViewStatusArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("yrskofwnbgiqaqxf")
    public suspend fun statuses(vararg argument: suspend InstanceViewStatusArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            InstanceViewStatusArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("kwvambmlknlxpikp")
    public suspend fun statuses(argument: suspend InstanceViewStatusArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(InstanceViewStatusArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.statuses = mapped
    }

    /**
     * @param values The resource status information.
     */
    @JvmName("kggelthlqhjcmtdy")
    public suspend fun statuses(vararg values: InstanceViewStatusArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statuses = mapped
    }

    /**
     * @param value The resource status information.
     */
    @JvmName("evvkwneiuvrefoqh")
    public suspend fun substatuses(`value`: List<InstanceViewStatusArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.substatuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("ixswwghlfvhwmput")
    public suspend fun substatuses(argument: List<suspend InstanceViewStatusArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            InstanceViewStatusArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.substatuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("iiucdfmgxnjkglve")
    public suspend fun substatuses(
        vararg
        argument: suspend InstanceViewStatusArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            InstanceViewStatusArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.substatuses = mapped
    }

    /**
     * @param argument The resource status information.
     */
    @JvmName("dexupesisjnjfaro")
    public suspend fun substatuses(argument: suspend InstanceViewStatusArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(InstanceViewStatusArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.substatuses = mapped
    }

    /**
     * @param values The resource status information.
     */
    @JvmName("ableafuyxnhwkvhk")
    public suspend fun substatuses(vararg values: InstanceViewStatusArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.substatuses = mapped
    }

    /**
     * @param value Specifies the type of the extension; an example is "CustomScriptExtension".
     */
    @JvmName("rovaqqqxicjwqpbj")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Specifies the version of the script handler.
     */
    @JvmName("fkjhxilymjpxxmmk")
    public suspend fun typeHandlerVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.typeHandlerVersion = mapped
    }

    internal fun build(): VirtualMachineExtensionInstanceViewArgs =
        VirtualMachineExtensionInstanceViewArgs(
            name = name,
            statuses = statuses,
            substatuses = substatuses,
            type = type,
            typeHandlerVersion = typeHandlerVersion,
        )
}
